@@ -129,7 +129,7 @@ module Sprockets
         args = attributes_for(logical_path).search_paths + [options]
         @trail.find(*args) do |path|
           pathname = Pathname.new(path)
-          if %w( bower.json component.json ).include?(pathname.basename.to_s)
+          if %w( .bower.json bower.json component.json ).include?(pathname.basename.to_s)
             bower = json_decode(pathname.read)
             case bower['main']
             when String
@@ -261,7 +261,7 @@ module Sprockets
     # Find asset by logical path or expanded path.
     def find_asset(path, options = {})
       logical_path = path
-      pathname     = Pathname.new(path)
+      pathname     = Pathname.new(path).cleanpath
 
       if pathname.absolute?
         return unless stat(pathname)
